#!/usr/bin/python
# -*- coding:utf-8 -*-

"""An abstract class of scoreboard classes.
"""

from dom import *
import scorecard
from loader import *

def newInstance():
    return Indy_SportsLine_2005()


class Indy_SportsLine_2005( scorecard.ScoreCard ):
    def __init__( self ):
        scorecard.ScoreCard.__init__( self )
        return

    """Overridable methods"""
    
    def getSportsCategory( self ):
        return "autoracing"

    def getCountry( self ):
        return "USA"

    def getName( self ):
        return "Indy Car (sportsline.com)"

    def getVersion( self ):
        return "1.0"

    def getIcon( self, team ):
        return ""

    def getEncoding( self ):
        return "latin1"

    def applyFilter( self, contents ):
        return contents

    def getLanguage( self ):
        return "en"

    def getURL( self ):
        return "http://www.sportsline.com/autoracing/results/OPEN_A"

    def interpreteDocument( self, document ):
        #print document
        elem = document.get_element_at_path( '/html/div/table/tr,3' )
        round = elem.get_text()
        date = ""
        elem = document.get_element_at_path( '/html/div/table/tr,4' )
        rows  = []
        while elem != None:
            data = elem.get_text( '-*-' ).split( '-*-' )
            if len( data ) >= 7:
                row = ( data[ 0 ], data[ 1 ], data[ 2 ], data[ 3 ], data[ 4 ] )
                rows.append( row )
                #print row
            elif len( data ) == 1:
                if data[ 0 ] != '':
                    date = data[ 0 ]
                pass
            else:
                #print len( data ), data
                pass
            #print elem.get_text( ',' )
            try:
                elem = elem.next_sibling( 'tr' )
            except:
                break
            pass
        self.table = { 'title':"Indy Car " + date, 'round':round,
                  'data':rows }
        return

    def getIgnorableTags( self ):
        return ( 'option', )

    def getStartKeyword( self ):
        return "Indy Racing League"

    def getEndKeyword( self ):
        return "<!-- AD for AUTO"

    def toHTML( self ):
        html  = self.html_header()
        html += '<span class="tabletitle">%s</span><br/>\n' % self.table[ 'title' ]
        html += '<span class="category">%s</span><br/>\n' % self.table[ 'round' ]
        html += '<table>\n'
        html += '<tr><th>Finish</th><th>Start</th><th>Driver</th><th>Manufacturer</th><th>Laps</th></tr>\n'
        for row in self.table[ 'data' ]:
            html += '<tr>'
            html += '<td class="rank">%s</td><td class="rank">%s</td><td class="driver">%s</td><td class="team">%s</td><td class="lap">%s</td>' % ( row[ 0 ], row[ 1 ], row[ 2 ], row[ 3 ], row[ 4 ] )
            html += '</tr>\n'
            pass
        html += '</table>'
        html += self.html_footer()
        return html

    def html_css_plugin( self ):
        return """<style type=\"text/css\">
        .rank {width:12px;height:12px;}
        .driver {width:120px;height:12px;text-align:center;font-weight:bold;}
        .team{width:120px;height:12px;font-weight:normal;}
        .laps{width:30px;height:12px;}
        .category{font-size:9px;margin-top:4px;}
        table tr td {height:14px;}
        </style>
        """
    pass


if __name__ == "__main__":
    
    import sys
    import tempfile
    from dom import *

    skin = None
    filename_input = None

    obj = newInstance()
    if len( sys.argv ) > 1: filename_input = sys.argv[ 1 ]
    
    if obj == None or obj.isAvailable() == False:
        print "invalid object"
        sys.exit()

    url = obj.getURL()
    encoding = obj.getEncoding()
    if filename_input:
        data = ""
        for line in open( filename_input ).readlines():
            data += line
            pass
        pass
    else:
        data = loadHTML( url, encoding )
        pass
    kw_start = obj.getStartKeyword()
    kw_end   = obj.getEndKeyword()
    parser = DOMConverter()
    for tag in obj.getIgnorableTags():
        parser.add_ignoring_tag( tag )
        pass
    if kw_start == None or kw_end == None:
        if encoding == None:
            parser.feed( obj.decode( obj.applyFilter( data ) ) )
        else:
            for line in data.split( "\n" ):
                parser.feed( obj.applyFilter( line ) )
                pass
            pass
        pass
    else:
        flag_inside = False
        parser.feed( '<html>' )
        for line in re.split( "\n", data ):
            line = obj.applyFilter( line )
            if encoding == None:
                line = obj.decode( line.strip() )
                pass
            if flag_inside:
                if line.count( kw_end ) > 0:
                    flag_inside = False
                    break
                else:
                    parser.feed( line )
                    pass
            elif line.count( kw_start ) > 0: flag_inside = True
            pass
        parser.feed( '</html>' )
        pass
    document = parser.get_document()
    obj.interpreteDocument( document )
    contents = obj.toHTML()
    print contents
